@@ -19,7 +19,7 @@
 
 /* Target triple LLVM will generate code for by default */
 /* Doesn't use `cmakedefine` because it is allowed to be empty. */
-#define LLVM_DEFAULT_TARGET_TRIPLE "mips64eb-unknown-netbsd10.0"
+#define LLVM_DEFAULT_TARGET_TRIPLE "armv6-unknown-netbsdelf11.99-eabihf"
 
 /* Define if threads enabled */
 #define LLVM_ENABLE_THREADS 1
@@ -28,32 +28,107 @@
 #define LLVM_HAS_ATOMICS 1
 
 /* Host triple LLVM will be executed on */
-#define LLVM_HOST_TRIPLE "mips64eb-unknown-netbsd10.0"
+#define LLVM_HOST_TRIPLE "armv6-unknown-netbsdelf11.99-eabihf"
 
 /* LLVM architecture name for the native architecture, if available */
-#define LLVM_NATIVE_ARCH Mips
+#define LLVM_NATIVE_ARCH ARM
 
 /* LLVM name for the native AsmParser init function, if available */
-#define LLVM_NATIVE_ASMPARSER LLVMInitializeMipsAsmParser
+#define LLVM_NATIVE_ASMPARSER LLVMInitializeARMAsmParser
 
 /* LLVM name for the native AsmPrinter init function, if available */
-#define LLVM_NATIVE_ASMPRINTER LLVMInitializeMipsAsmPrinter
+#define LLVM_NATIVE_ASMPRINTER LLVMInitializeARMAsmPrinter
 
 /* LLVM name for the native Disassembler init function, if available */
-#define LLVM_NATIVE_DISASSEMBLER LLVMInitializeMipsDisassembler
+#define LLVM_NATIVE_DISASSEMBLER LLVMInitializeARMDisassembler
 
 /* LLVM name for the native Target init function, if available */
-#define LLVM_NATIVE_TARGET LLVMInitializeMipsTarget
+#define LLVM_NATIVE_TARGET LLVMInitializeARMTarget
 
 /* LLVM name for the native TargetInfo init function, if available */
-#define LLVM_NATIVE_TARGETINFO LLVMInitializeMipsTargetInfo
+#define LLVM_NATIVE_TARGETINFO LLVMInitializeARMTargetInfo
 
 /* LLVM name for the native target MC init function, if available */
-#define LLVM_NATIVE_TARGETMC LLVMInitializeMipsTargetMC
+#define LLVM_NATIVE_TARGETMC LLVMInitializeARMTargetMC
 
 /* LLVM name for the native target MCA init function, if available */
 /* #undef LLVM_NATIVE_TARGETMCA */
 
+/* Define if the AArch64 target is built in */
+#define LLVM_HAS_AARCH64_TARGET 0
+
+/* Define if the AMDGPU target is built in */
+#define LLVM_HAS_AMDGPU_TARGET 0
+
+/* Define if the ARC target is built in */
+#define LLVM_HAS_ARC_TARGET 0
+
+/* Define if the ARM target is built in */
+#define LLVM_HAS_ARM_TARGET 1
+
+/* Define if the AVR target is built in */
+#define LLVM_HAS_AVR_TARGET 0
+
+/* Define if the BPF target is built in */
+#define LLVM_HAS_BPF_TARGET 0
+
+/* Define if the CSKY target is built in */
+#define LLVM_HAS_CSKY_TARGET 0
+
+/* Define if the DirectX target is built in */
+#define LLVM_HAS_DIRECTX_TARGET 0
+
+/* Define if the Hexagon target is built in */
+#define LLVM_HAS_HEXAGON_TARGET 0
+
+/* Define if the Lanai target is built in */
+#define LLVM_HAS_LANAI_TARGET 0
+
+/* Define if the LoongArch target is built in */
+#define LLVM_HAS_LOONGARCH_TARGET 0
+
+/* Define if the M68k target is built in */
+#define LLVM_HAS_M68K_TARGET 0
+
+/* Define if the Mips target is built in */
+#define LLVM_HAS_MIPS_TARGET 0
+
+/* Define if the MSP430 target is built in */
+#define LLVM_HAS_MSP430_TARGET 0
+
+/* Define if the NVPTX target is built in */
+#define LLVM_HAS_NVPTX_TARGET 0
+
+/* Define if the PowerPC target is built in */
+#define LLVM_HAS_POWERPC_TARGET 0
+
+/* Define if the RISCV target is built in */
+#define LLVM_HAS_RISCV_TARGET 0
+
+/* Define if the Sparc target is built in */
+#define LLVM_HAS_SPARC_TARGET 0
+
+/* Define if the SPIRV target is built in */
+#define LLVM_HAS_SPIRV_TARGET 0
+
+/* Define if the SystemZ target is built in */
+#define LLVM_HAS_SYSTEMZ_TARGET 0
+
+/* Define if the VE target is built in */
+#define LLVM_HAS_VE_TARGET 0
+
+/* Define if the WebAssembly target is built in */
+#define LLVM_HAS_WEBASSEMBLY_TARGET 0
+
+/* Define if the X86 target is built in */
+#define LLVM_HAS_X86_TARGET 0
+
+/* Define if the XCore target is built in */
+#define LLVM_HAS_XCORE_TARGET 0
+
+/* Define if the Xtensa target is built in */
+#define LLVM_HAS_XTENSA_TARGET 0
+
 /* Define if this is Unixish platform */
 #define LLVM_ON_UNIX 1
 
@@ -67,16 +142,16 @@
 #define LLVM_USE_PERF 0
 
 /* Major version of the LLVM API */
-#define LLVM_VERSION_MAJOR 17
+#define LLVM_VERSION_MAJOR 19
 
 /* Minor version of the LLVM API */
-#define LLVM_VERSION_MINOR 0
+#define LLVM_VERSION_MINOR 1
 
 /* Patch version of the LLVM API */
-#define LLVM_VERSION_PATCH 6
+#define LLVM_VERSION_PATCH 7
 
 /* LLVM version string */
-#define LLVM_VERSION_STRING "17.0.6"
+#define LLVM_VERSION_STRING "19.1.7"
 
 /* Whether LLVM records statistics for use with GetStatistics(),
  * PrintStatistics() or PrintStatisticsJSON()
@@ -98,15 +173,12 @@
 /* Define if zstd compression is available */
 #define LLVM_ENABLE_ZSTD 1
 
-/* Define if LLVM is using tflite instead of libtensorflow */
+/* Define if LLVM is using tflite */
 /* #undef LLVM_HAVE_TFLITE */
 
 /* Define to 1 if you have the <sysexits.h> header file. */
 #define HAVE_SYSEXITS_H 1
 
-/* Define if the xar_open() function is supported on this platform. */
-/* #undef LLVM_HAVE_LIBXAR */
-
 /* Define if building libLLVM shared library */
 #define LLVM_BUILD_LLVM_DYLIB
 
@@ -126,4 +198,7 @@
 /* Define if plugins enabled */
 #define LLVM_ENABLE_PLUGINS
 
+/* Define if logf128 is available */
+/* #undef LLVM_HAS_LOGF128 */
+
 #endif
